@@ -157,6 +157,6 @@ function(d, n, B=0,DB=c(0,0), JC=FALSE, CI_Boot,  type="bca", plot=FALSE){
   if(B>0){return(Estimate_Bootstrap)}
   if(JC==TRUE){return(Estimate_Jackknife)}
   if(DB[1]!=0){return(Estimate_DoubleBootstrap)}
-  if(B==0 && JC==FALSE && DB==0){return(Estimate_Standard)}
+  if(B==0 && JC==FALSE && DB[1]==0){return(Estimate_Standard)}
   
 }
