@@ -244,7 +244,7 @@ intraMLE <-
     if(B>0){return(Estimate_Bootstrap)}
     if(JC==TRUE){return(Estimate_Jackknife)}
     if(DB[1]!=0){return(Estimate_DoubleBootstrap)}
-    if(B==0 && JC==FALSE && DB==0){return(Estimate_Standard)}
+    if(B==0 && JC==FALSE && DB[1]==0){return(Estimate_Standard)}
     
     
   }
